==> clarity-demos-0.6.3.tgz: package/src/dropdown/demo/dropdown.demo.routing.ts <==
import {ModuleWithProviders} from "@angular/core/src/metadata/ng_module";
import {Routes, RouterModule} from "@angular/router";

import {DropdownDemo} from "./dropdown.demo";
import {DropdownStaticDefaultDemo} from "./dropdown-static-default";
import {DropdownStaticPositioningDemo} from "./dropdown-static-positioning";
import {DropdownStaticFontAwesomeToggleDemo} from "./dropdown-static-fontawesome-toggle";
import {DropdownStaticIconToggleDemo} from "./dropdown-static-icon-toggle";
import {DropdownStaticTextLinkToggleDemo} from "./dropdown-static-textlink-toggle";
import {DropdownAngularPositioningDemo} from "./dropdown-angular-positioning";
import {DropdownAngularCloseItemFalseDemo} from "./dropdown-angular-close-item-false";

const ROUTES: Routes = [
    {
        path: "",
        component: DropdownDemo,
        children: [
            { path: "", redirectTo: "default", pathMatch: "full" },
            { path: "default", component: DropdownStaticDefaultDemo },
            { path: "positioning", component: DropdownStaticPositioningDemo },
            { path: "fontawesome-toggle", component: DropdownStaticFontAwesomeToggleDemo },
            { path: "icon-toggle", component: DropdownStaticIconToggleDemo },
            { path: "textlink-toggle", component: DropdownStaticTextLinkToggleDemo },
            { path: "angular-positioning", component: DropdownAngularPositioningDemo },
            { path: "multi-click", component: DropdownAngularCloseItemFalseDemo }
        ]
    }
];

export const ROUTING: ModuleWithProviders = RouterModule.forChild(ROUTES);

==> clarity-demos-0.7.6.tgz: package/src/dropdown/demo/dropdown.demo.routing.ts <==
/*
 * Copyright (c) 2016 VMware, Inc. All Rights Reserved.
 * This software is released under MIT license.
 * The full license information can be found in LICENSE in the root directory of this project.
 */
import {ModuleWithProviders} from "@angular/core/src/metadata/ng_module";
import {Routes, RouterModule} from "@angular/router";

import {DropdownDemo} from "./dropdown.demo";
import {DropdownStaticDefaultDemo} from "./dropdown-static-default";
import {DropdownStaticPositioningDemo} from "./dropdown-static-positioning";
import {DropdownStaticFontAwesomeToggleDemo} from "./dropdown-static-fontawesome-toggle";
import {DropdownStaticIconToggleDemo} from "./dropdown-static-icon-toggle";
import {DropdownStaticButtonLinkToggleDemo} from "./dropdown-static-buttonlink-toggle";
import {DropdownAngularPositioningDemo} from "./dropdown-angular-positioning";
import {DropdownAngularCloseItemFalseDemo} from "./dropdown-angular-close-item-false";

const ROUTES: Routes = [
    {
        path: "",
        component: DropdownDemo,
        children: [
            { path: "", redirectTo: "default", pathMatch: "full" },
            { path: "default", component: DropdownStaticDefaultDemo },
            { path: "positioning", component: DropdownStaticPositioningDemo },
            { path: "fontawesome-toggle", component: DropdownStaticFontAwesomeToggleDemo },
            { path: "icon-toggle", component: DropdownStaticIconToggleDemo },
            { path: "buttonlink-toggle", component: DropdownStaticButtonLinkToggleDemo },
            { path: "angular-positioning", component: DropdownAngularPositioningDemo },
            { path: "multi-click", component: DropdownAngularCloseItemFalseDemo }
        ]
    }
];

export const ROUTING: ModuleWithProviders = RouterModule.forChild(ROUTES);
